package com.cse340.spottheheron;

import androidx.appcompat.app.AppCompatActivity;

import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import android.view.View;
import android.view.animation.Animation;
import android.widget.ImageView;
import android.widget.ViewFlipper;

public class MainActivity extends AppCompatActivity {

    /** List of images in the drawable directory */
    private String[] images = {"cold", "dontcare", "fishing", "flying",
            "gru", "hidden", "log", "lonely", "reeds", "reflection", "sunrise",
            "treebird", "wading"};

    /** Index of currently selected Image */
    private int whichImage;

    /** Whether we're in the slideshow or not */
    private boolean inSlideshow = false;

    /** How many seconds between flipping images in the image view */
    private static final int SLIDESHOW_TIME = 1500;

    // Magic thread that will switch images.. uses a handler to make sure the
    // switching happens on the same thread as the UI
    private Runnable runnable = new Runnable() {
        @Override
        public void run() {
            intervalImage();
        }
    };

    private Handler handler;

    // Callback to handle the previous button
    private View.OnClickListener mPrevListener = new View.OnClickListener() {
        public void onClick(View v) {
            switchImage(false);

        }
    };

    // Callback to handle the slideshow button
    private View.OnClickListener mSlideShowListener = new View.OnClickListener() {
        public void onClick(View v) {
            if (!inSlideshow) {
                //sets image to flip in SLIDESHOW_TIME ms.
                handler.postDelayed(runnable, SLIDESHOW_TIME);
            }
            else {
                //turns off auto flipping
                handler.removeCallbacks(runnable);
            }
            inSlideshow = !inSlideshow;
        }
    };

    // Callback to handle the next button
    private View.OnClickListener mNextListener = new View.OnClickListener() {
        public void onClick(View v) {
            switchImage(true);
        }
    };


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        getSupportActionBar().hide();

        inSlideshow = false;

        // Stack overflow magic. There's a lot of complicated code out there, but this
        // actually got the job done:  https://stackoverflow.com/questions/29713990/how-to-change-images-in-imageview-every-n-number-of-seconds
        // Note to self: don't try to learn Android timers 12 hours before giving a lecture.
        handler = new Handler(Looper.getMainLooper());

        ImageView mNextButton = findViewById(R.id.next);
        if (mNextButton != null) {
            mNextButton.setOnClickListener(mNextListener);
        }

        ImageView mPrevButton =  findViewById(R.id.prev);
        if (mPrevButton != null) {
            mPrevButton.setOnClickListener(mPrevListener);
        }

        ImageView mSlideShowButton =  findViewById(R.id.slideshow);
        if (mSlideShowButton != null) {
            mSlideShowButton.setOnClickListener(mSlideShowListener);
        }


        whichImage = 0;
        loadImage(whichImage);
    }

    /** Method to load an image from the images array into the heronView ImageView interactor
     *
     * @param img the number of the image to load, assumes 0 <= img < images.length
     */
    private void loadImage(int img) {
        int resID = getResources().getIdentifier(images[img], "drawable", getPackageName());
        ImageView heronView = findViewById(R.id.heronView);
        heronView.setImageResource(resID);
        heronView.setContentDescription(images[img]);

    }

    /** Method to move onto the next or previous image, depending on the flag passed in
     *
     * @param forward true if you are to go to the next image, false if not.
     */
    private void switchImage(boolean forward) {
        if (forward) {
            if (whichImage == images.length - 1)
                whichImage = 0;
            else
                whichImage++;
        }
        else {
            if (whichImage == 0)
                whichImage = images.length - 1;
            else
                whichImage--;
        }
        loadImage(whichImage);
    }

    /** Method to keep flipping the images.
     *
     */
    private void intervalImage() {
        // Switches image
        switchImage(true);
        // tells the app to switch again in SLIDESHOW_TIME ms
        handler.postDelayed(runnable, SLIDESHOW_TIME);

    }

}
